==> bind-9.9.1-P3.tar.gz: bind-9.9.1-P3/bin/tests/system/runall.sh <==
#!/bin/sh
#
# Copyright (C) 2004, 2007, 2010, 2011  Internet Systems Consortium, Inc. ("ISC")
# Copyright (C) 2000, 2001  Internet Software Consortium.
#
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
# REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
# AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
# INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
# LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
# OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
# PERFORMANCE OF THIS SOFTWARE.

# $Id: runall.sh,v 1.13 2011/12/19 23:08:50 marka Exp $

#
# Run all the system tests.
#

SYSTEMTESTTOP=.
. $SYSTEMTESTTOP/conf.sh

status=0

{
    for d in $SUBDIRS
    do
            sh run.sh $d || status=1
    done

    $PERL testsock.pl || {
        cat <<EOF >&2
I:
I:NOTE: Many of the tests were skipped because they require that
I:      the IP addresses 10.53.0.1 through 10.53.0.7 are configured 
I:	as alias addresses on the loopback interface.  Please run
I:	"bin/tests/system/ifconfig.sh up" as root to configure them
I:	and rerun the tests.
EOF
        exit 0;
    }
} | tee "systests.output"

echo "I:System test result summary:"
grep '^R:' systests.output | sort | uniq -c | sed -e 's/^/I:   /' -e 's/R://'
grep '^R:FAIL' systests.output > /dev/null && status=1

exit $status

==> bind-9.10.2-P3.tar.gz: bind-9.10.2-P3/bin/tests/system/runall.sh <==
#!/bin/sh
#
# Copyright (C) 2004, 2007, 2010-2012, 2014  Internet Systems Consortium, Inc. ("ISC")
# Copyright (C) 2000, 2001  Internet Software Consortium.
#
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
# REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
# AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
# INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
# LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
# OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
# PERFORMANCE OF THIS SOFTWARE.

#
# Run all the system tests.
#

SYSTEMTESTTOP=.
. $SYSTEMTESTTOP/conf.sh

status=0

{
    for d in $SUBDIRS
    do
            $SHELL run.sh $d || status=1
    done
} 2>&1 | tee "systests.output"

$PERL testsock.pl || {
    cat <<EOF >&2
I:
I:NOTE: System tests were skipped because they require that the
I:      IP addresses 10.53.0.1 through 10.53.0.8 be configured
I:      as alias addresses on the loopback interface.  Please run
I:      "bin/tests/system/ifconfig.sh up" as root to configure them.
EOF
}

echo "I:System test result summary:"
grep '^R:' systests.output | sort | uniq -c | sed -e 's/^/I: /' -e 's/R://'
grep '^R:FAIL' systests.output > /dev/null && status=1

exit $status
